==> open-xchange-gui-wizard-plugin_6.16.1.0.orig.tar.gz: open-xchange-gui-wizard-plugin-6.16.1.0/gui/config.js <==
/**
 * 
 * All content on this website (including text, images, source
 * code and any other original works), unless otherwise noted,
 * is licensed under a Creative Commons License.
 * 
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 * 
 * Copyright (C) 2004-2007 Open-Xchange, Inc.
 * Mail: info@open-xchange.com 
 * 
 * @author Ben Pahne <ben.pahne@open-xchange.com>
 * 
 */

var wizardLaunchOnStart = true;

var wizardTabServices = true;
var wizardTabPersonalData = true;
var wizardTabMobility = true;
var wizardTabUpsell = false;
var wizardTabPuplish = true;

var wizardUpsellLayerTabUrl = "plugins/com.openexchange.wizard/upsell.html";


var	wizzardMobilityNokia = true;
var wizzardMobilityWindowsMobile = true;
var wizzardMobilityiPhone = true;
var wizzardMobilityBlackBerry = true;

var wizzardwithMSNService = false;
var wizzardwithTOnlineService = false;


// tonline smtp transport settings
var wizard_tonline_transport_service = "securesmtp.t-online.de";
var wizard_tonline_transport_service_port = "465";

// tonline imap & pop3 settings
var wizard_tonline_pop_server = "securepop.t-online.de";
var wizard_tonline_pop_port = "995";


// gmx smtp transport settings
var wizard_gmx_transport_service = "mail.gmx.com";
var wizard_gmx_transport_service_port = "465";

// gmx imap & pop3 settings
var wizard_gmx_imap_server = "imap.gmx.com";
var wizard_gmx_imap_port = "993";
var wizard_gmx_pop_server = "pop.gmx.com";
var wizard_gmx_pop_port = "995";


// msn smtp transport settings
var wizard_msn_transport_service = "smtp.live.com";
var wizard_msn_transport_service_port = "465";

// msn imap & pop3 settings
var wizard_msn_pop_server = "pop3.live.com";
var wizard_msn_pop_port = "995";


// gmail smtp transport settings
var wizard_gmail_transport_service = "smtp.gmail.com";
var wizard_gmail_transport_port = "465";

// gmail imap & pop3 settings
var wizard_gmail_imap_server = "imap.gmail.com";
var wizard_gmail_imap_port = "993";
var wizard_gmail_pop_server = "pop.gmail.com";
var wizard_gmail_pop_port = "995";



// yahoo pro and normal smtp
var wizard_yahoo_plus_transport_service = "plus.smtp.mail.yahoo.com";
var wizard_yahoo_transport_service = "smtp.mail.yahoo.com";
var wizard_yahoo_transport_service_port = "465"

// yahoo pro and normal pop
var wizard_yahoo_plus_pop_server = "plus.pop.mail.yahoo.com";
var wizard_yahoo_pop_service = "pop.mail.yahoo.com";
var wizard_yahoo_pop_port = "995";



// web.de smtp transport settings
var wizard_webde_transport_service = "smtp.web.de";
var wizard_webde_transport_service_port = "25";

//  web.de imap & pop3 settings
var wizard_webde_imap_server = "imap.web.de";
var wizard_webde_imap_port = "993";
var wizard_webde_pop_server = "pop3.web.de";
var wizard_webde_pop_port = "995";

==> open-xchange-gui-wizard-plugin_6.18.0.0.orig.tar.gz: open-xchange-gui-wizard-plugin-6.18.0.0/gui/config.js <==
/**
 * 
 * All content on this website (including text, images, source
 * code and any other original works), unless otherwise noted,
 * is licensed under a Creative Commons License.
 * 
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 * 
 * Copyright (C) 2004-2007 Open-Xchange, Inc.
 * Mail: info@open-xchange.com 
 * 
 * @author Ben Pahne <ben.pahne@open-xchange.com>
 * 
 */

var wizardLaunchOnStart = true;

var wizardTabServices = true;
var wizardTabPersonalData = true;
var wizardTabMobility = true;
var wizardTabUpsell = false;
var wizardTabPuplish = true;

var wizardUpsellLayerTabUrl = "plugins/com.openexchange.wizard/upsell.html";


var	wizzardMobilityNokia = true;
var wizzardMobilityWindowsMobile = true;
var wizzardMobilityiPhone = true;
var wizzardMobilityBlackBerry = true;

var wizzardwithMSNService = false;
var wizzardwithTOnlineService = false;


// tonline smtp transport settings
var wizard_tonline_transport_service = "securesmtp.t-online.de";
var wizard_tonline_transport_service_port = "465";

// tonline imap & pop3 settings
var wizard_tonline_pop_server = "securepop.t-online.de";
var wizard_tonline_pop_port = "995";


// gmx smtp transport settings
var wizard_gmx_transport_service = "mail.gmx.com";
var wizard_gmx_transport_service_port = "465";

// gmx imap & pop3 settings
var wizard_gmx_imap_server = "imap.gmx.com";
var wizard_gmx_imap_port = "993";
var wizard_gmx_pop_server = "pop.gmx.com";
var wizard_gmx_pop_port = "995";


// msn smtp transport settings
var wizard_msn_transport_service = "smtp.live.com";
var wizard_msn_transport_service_port = "465";

// msn imap & pop3 settings
var wizard_msn_pop_server = "pop3.live.com";
var wizard_msn_pop_port = "995";


// gmail smtp transport settings
var wizard_gmail_transport_service = "smtp.gmail.com";
var wizard_gmail_transport_port = "465";

// gmail imap & pop3 settings
var wizard_gmail_imap_server = "imap.gmail.com";
var wizard_gmail_imap_port = "993";
var wizard_gmail_pop_server = "pop.gmail.com";
var wizard_gmail_pop_port = "995";



// yahoo pro and normal smtp
var wizard_yahoo_plus_transport_service = "plus.smtp.mail.yahoo.com";
var wizard_yahoo_transport_service = "smtp.mail.yahoo.com";
var wizard_yahoo_transport_service_port = "465";

// yahoo pro and normal pop
var wizard_yahoo_plus_pop_server = "plus.pop.mail.yahoo.com";
var wizard_yahoo_pop_service = "pop.mail.yahoo.com";
var wizard_yahoo_pop_port = "995";



// web.de smtp transport settings
var wizard_webde_transport_service = "smtp.web.de";
var wizard_webde_transport_service_port = "25";

//  web.de imap & pop3 settings
var wizard_webde_imap_server = "imap.web.de";
var wizard_webde_imap_port = "993";
var wizard_webde_pop_server = "pop3.web.de";
var wizard_webde_pop_port = "995";
